/*
 * Copyright 2024 NXP
 * All rights reserved.
 *
 * SPDX-License-Identifier: BSD-3-Clause
 */

/**
 * @file frdmmcxa156.c
 * @brief The frdmmcxa156.c file defines GPIO pins and I2C CMSIS utilities for frdmmcxa156 board.
 */

#include <frdmmcxa156.h>

// I2C2 Pin Handles
gpioHandleKSDK_t D14 = {.base = GPIO3, .pinNumber = P28_IDX, .mask = 1 << (P28_IDX), .clockName = kCLOCK_GateGPIO3, .portNumber = PORTD_NUM};
gpioHandleKSDK_t D15 = {.base = GPIO3, .pinNumber = P27_IDX, .mask = 1 << (P27_IDX), .clockName = kCLOCK_GateGPIO3, .portNumber = PORTD_NUM};

// SPI1 Handle
/* [PIO0_20] (coords: 74) configured as SPI master-out/slave-in (MOSI) data */
gpioHandleKSDK_t D11 = {.base = GPIO3, .pinNumber = P9_IDX, .mask = 1 << (P9_IDX), .clockName = kCLOCK_GateGPIO3, .portNumber = PORTD_NUM};
/* [PIO0_19] (coords: 90) is configured as SPI master-in/slave-out (MISO) data */
gpioHandleKSDK_t D12 = {.base = GPIO3, .pinNumber = P8_IDX, .mask = 1 << (P8_IDX), .clockName = kCLOCK_GateGPIO3, .portNumber = PORTD_NUM};
/* [PIO0_21] (coords: 76) configured as SPI SCK */
gpioHandleKSDK_t D13 = {.base = GPIO3, .pinNumber = P10_IDX, .mask = 1 << (P10_IDX), .clockName = kCLOCK_GateGPIO3, .portNumber = PORTD_NUM};
/* [PIO0_21] (coords: 76) configured as SPI SCK */
gpioHandleKSDK_t D10 = {.base = GPIO3, .pinNumber = P11_IDX, .mask = 1 << (P11_IDX), .clockName = kCLOCK_GateGPIO3, .portNumber = PORTD_NUM};

gpioHandleKSDK_t D2 = {.base = GPIO2, .pinNumber = P5_IDX, .mask = 1 << (P5_IDX), .clockName = kCLOCK_GateGPIO2, .portNumber = PORTC_NUM};

// LPCXpresso55s69 Internal Peripheral Pin Definitions
gpioHandleKSDK_t RED_LED = {
    .base = GPIO3, .pinNumber = P12_IDX, .mask = 1 << (P12_IDX), .clockName = kCLOCK_GateGPIO3, .portNumber = PORTD_NUM};
gpioHandleKSDK_t GREEN_LED = {
    .base = GPIO3, .pinNumber = P13_IDX, .mask = 1 << (P13_IDX), .clockName = kCLOCK_GateGPIO3, .portNumber = PORTD_NUM};
gpioHandleKSDK_t BLUE_LED = {
    .base = GPIO3, .pinNumber = P0_IDX, .mask = 1 << (P0_IDX), .clockName = kCLOCK_GateGPIO3, .portNumber = PORTD_NUM};

/*!
 * @brief Configures the system to WAIT power mode.
 *        API name used from Kinetis family to maintain compatibility.
 *
 * @param Power peripheral base address (dummy).
 * @return Configuration error code.
 */
status_t SMC_SetPowerModeWait(void *arg)
{
    // POWER_EnterSleep();

    return kStatus_Success;
}

/*!
 * @brief Configures the system to VLPR power mode.
 *        API name used from Kinetis family to maintain compatibility.
 *
 * @param Power peripheral base address (dummy).
 * @return Configuration error code.
 */
status_t SMC_SetPowerModeVlpr(void *arg)
{
    // POWER_EnterSleep();

    return kStatus_Success;
}

/*! @brief       Determines the Clock Frequency feature.
 *  @details     The Clock Frequecny computation API required by fsl_uart_cmsis.c.
 *  @param[in]   void
 *  @Constraints None
 *  @Reentrant   Yes
 *  @return      uint32_t Returns the clock frequency .
 */
uint32_t LPUART0_GetFreq(void)
{
    return CLOCK_GetLpuartClkFreq(0u);
}

/*! @brief       Determines the Clock Frequency feature.
 *  @details     The Clock Frequecny computation API required by fsl_i2c_cmsis.c.
 *  @param[in]   void
 *  @Constraints None
 *  @Reentrant   Yes
 *  @return      uint32_t Returns the clock frequency .
 */
uint32_t LPI2C0_GetFreq(void)
{
    /* Attach peripheral clock */
    CLOCK_SetupFRO12MClocking();
    CLOCK_SetClockDiv(kCLOCK_DivLPI2C0, 1u);
    CLOCK_AttachClk(kFRO12M_to_LPI2C0);

    return CLOCK_GetLpi2cClkFreq(0U);
}

/*! @brief       Determines the Clock Frequency feature.
 *  @details     The Clock Frequecny computation API required by fsl_spi_cmsis.c.
 *  @param[in]   void
 *  @Constraints None
 *  @Reentrant   Yes
 *  @return      uint32_t Returns the clock frequency .
 */
uint32_t LPSPI1_GetFreq(void)
{
    /* Attach peripheral clock */
    /* Attach peripheral clock */
    CLOCK_SetClockDiv(kCLOCK_DivLPSPI1, 1u);
    CLOCK_AttachClk(kFRO12M_to_LPSPI1);

    return CLOCK_GetLpspiClkFreq(1);
}
