/*
 * Copyright 2024 NXP
 * All rights reserved.
 *
 * SPDX-License-Identifier: BSD-3-Clause
 */
/**
 * @file frdmmcxa156.h
 * @brief The frdmmcxa156.h file defines GPIO pin mappings for frdmmcxa156 board
 */

#ifndef FRDM_MCXA153_H_
#define FRDM_MCXA153_H_

#include "pin_mux.h"
#include "RTE_Device.h"
#include "gpio_driver.h"
#include "clock_config.h"
#include "board.h"

// I2C4 Pin Handles
extern gpioHandleKSDK_t D14;
extern gpioHandleKSDK_t D15;

// SPI7 Handles
extern gpioHandleKSDK_t D11;
extern gpioHandleKSDK_t D12;
extern gpioHandleKSDK_t D13;
extern gpioHandleKSDK_t D10;

// UART0 Handle
extern gpioHandleKSDK_t D0;
extern gpioHandleKSDK_t D1;

extern gpioHandleKSDK_t D2;

// LPCXpresso54114 Internal Peripheral Pin Definitions
extern gpioHandleKSDK_t RED_LED;
extern gpioHandleKSDK_t GREEN_LED;
extern gpioHandleKSDK_t BLUE_LED;

typedef enum p_number
{
    P0_IDX  = 0,
    P1_IDX  = 1,
    P2_IDX  = 2,
    P3_IDX  = 3,
    P4_IDX  = 4,
    P5_IDX  = 5,
    P6_IDX  = 6,
    P7_IDX  = 7,
    P8_IDX  = 8,
    P9_IDX  = 9,
    P10_IDX = 10,
    P11_IDX = 11,
    P12_IDX = 12,
    P13_IDX = 13,
    P14_IDX = 14,
    P15_IDX = 15,
    P16_IDX = 16,
    P17_IDX = 17,
    P18_IDX = 18,
    P19_IDX = 19,
    P20_IDX = 20,
    P21_IDX = 21,
    P22_IDX = 22,
    P23_IDX = 23,
    P24_IDX = 24,
    P25_IDX = 25,
    P26_IDX = 26,
    P27_IDX = 27,
    P28_IDX = 28,
    P29_IDX = 29,
    TOTAL_P_NUMBER
} p_number_t;

// I2C_S1: Pin mapping and driver information for default I2C brought to shield
#define I2C_S1_SCL_PIN      D15
#define I2C_S1_SDA_PIN      D14
#define I2C_S1_DRIVER       Driver_I2C0
#define I2C_S1_DEVICE_INDEX I2C0_INDEX
#define I2C_S1_SIGNAL_EVENT I2C0_SignalEvent_t

// SPI_S: Pin mapping and driver information default SPI brought to shield
#define SPI_S_DRIVER       Driver_SPI1
#define SPI_S_BAUDRATE     500000U ///< Transfer baudrate - 500k
#define SPI_S_DEVICE_INDEX SPI1_INDEX
#define SPI_S_SIGNAL_EVENT SPI1_SignalEvent_t

// UART: Driver information for default UART to communicate with HOST PC.
#define HOST_S_DRIVER       Driver_USART0
#define HOST_S_SIGNAL_EVENT HOST_SignalEvent_t
#define HOST_B_DRIVER       Driver_USART1
#define HOST_B_SIGNAL_EVENT HOST_SignalEvent_t

/* @brief  Ask use input to resume after specified samples have been processed. */
#define ASK_USER_TO_RESUME(x)                                                          \
    static bool askResume            = true;                                           \
    static uint16_t samplesToProcess = x - 1;                                          \
    if (askResume && !samplesToProcess--)                                              \
    {                                                                                  \
        PRINTF("\r\n Specified samples processed, press any key to continue... \r\n"); \
        GETCHAR();                                                                     \
        askResume = false;                                                             \
    }

/* @brief dummy arguement to Power Mode Wait Wrapper. */
#define SMC NULL
#define I2C0 LPI2C0
#define SPI1 LPSPI1

/* @brief Kinetis style Wrapper API for Power Mode Wait (Wait for Interrupt). */
status_t SMC_SetPowerModeWait(void *arg);
/* @brief Kinetis style Wrapper API for Power Mode VLPR (Wait for Interrupt). */
status_t SMC_SetPowerModeVlpr(void *arg);
/* @brief Kinetis style Wrapper API for handling all Clock related configurations. */
void BOARD_BootClockRUN(void);
#endif /* FRDM_MCXA153_H_ */
